@@ -1,10 +1,10 @@
 /*
     license
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "license.h"
 #include "misc.h"
@@ -29,7 +28,7 @@ typedef struct _LicenseDlg
 {
   gboolean *display;
   gint count;
-  GtkWidget *textview, *hbox;
+  GtkWidget *textview, *hbox, *label;
 } LicenseDlg;
 
 
@@ -37,6 +36,7 @@ typedef struct _LicenseDlg
 static gboolean
 license_dialog_timeout (LicenseDlg *ld)
 {
+  gboolean result = TRUE;
   gint i, st, ed;
   GtkTextIter iter;
   GdkRectangle visible_rect;
@@ -58,16 +58,27 @@ license_dialog_timeout (LicenseDlg *ld)
       break;
   if (i < 0)
     {
+      /* ja:ライセンスをすべて表示した */
       gtk_widget_set_sensitive (ld->hbox, TRUE);
-#ifdef USE_THREAD
-      gdk_threads_leave ();
-#endif /* USE_THREAD */
-      return FALSE;
+      gtk_widget_hide (ld->label);
+      result = FALSE;
+    }
+  else if (!GTK_WIDGET_VISIBLE (ld->label))
+    {
+      /* ja:1画面にライセンスをすべて表示できなかったとき */
+      g_memset (ld->display, 0, ld->count * sizeof (gboolean));
+      gtk_widget_show (ld->label);
+    }
+  else if (ld->display[0] && ld->display[ld->count - 1])
+    {
+      /* ja:中途半端にライセンスが表示されているとき */
+      gtk_label_set_text (GTK_LABEL (ld->label), _("Scroll is too fast!"
+                                        " Do you really view the license?"));
     }
 #ifdef USE_THREAD
   gdk_threads_leave ();
 #endif /* USE_THREAD */
-  return TRUE;
+  return result;
 }
 
 
@@ -100,7 +111,7 @@ license_dialog (const gchar *text)
                             NULL);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
   gtk_window_set_default_size (GTK_WINDOW (dialog),
-                                            0, gdk_screen_height () * 2 / 3);
+                    gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
   g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:テキスト */
@@ -110,16 +121,23 @@ license_dialog (const gchar *text)
   gtk_text_view_set_editable (GTK_TEXT_VIEW (ld.textview), FALSE);
   ld.count = gtk_text_buffer_get_line_count (buffer);
   ld.display = g_malloc0 (ld.count * sizeof (gboolean));
+  gtk_widget_show (ld.textview);
   /* ja:スクロールウインドウ */
   scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
                                     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
   gtk_container_add (GTK_CONTAINER (scroll), ld.textview);
+  gtk_widget_show (scroll);
+  /* ja:ラベル */
+  ld.label = gtk_label_new (_("View the license."
+                        " Please scroll to view the entire license text."));
   /* ja:ラジオボタン */
   radio0 = gtk_radio_button_new_with_label (NULL, _("I agree."));
   radio1 = gtk_radio_button_new_with_label_from_widget
                                 (GTK_RADIO_BUTTON (radio0), _("I deny."));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio1), TRUE);
+  gtk_widget_show (radio0);
+  gtk_widget_show (radio1);
   /* ja:フレームとボックス */
   ld.hbox = gtk_hbox_new (FALSE, SPACING);
 #ifdef G_OS_WIN32
@@ -129,15 +147,17 @@ license_dialog (const gchar *text)
   gtk_box_pack_start (GTK_BOX (ld.hbox), radio1, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (ld.hbox), radio0, FALSE, FALSE, 0);
 #endif /* not G_OS_WIN32 */
+  gtk_widget_show (ld.hbox);
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), ld.hbox, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (vbox), ld.label, FALSE, FALSE, 0);
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
+  gtk_widget_show (vbox);
 
   /* ja:表示 */
   gtk_widget_set_sensitive (ld.hbox, FALSE);
-  gtk_widget_show_all (vbox);
 
   timer_id = g_timeout_add (100, (GSourceFunc)license_dialog_timeout, &ld);
 #ifdef USE_THREAD
