@@ -121,6 +121,23 @@ const gchar *
 misc_spec_locale (const gchar *prgname);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:クローズボタン関数群                                                     *
+*                                                                             *
+******************************************************************************/
+/*  ja:クローズボタンのイメージを取得する
+    RET,イメージ,NULL:エラー                                                */
+GtkWidget *
+misc_close_image (void);
+
+
+/*  ja:クローズボタンを取得する
+    RET,ボタン,NULL:エラー                                                  */
+GtkWidget *
+misc_close_button (void);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:低レベル関数群                                                           *
