@@ -32,7 +32,7 @@ WinMain (HINSTANCE hInstance,
 {
 #if GLIB_CHECK_VERSION(2,6,0)
   char **argv;
-  int i, argc, ret = -1;
+  int i, argc, ret;
 
   if (G_WIN32_HAVE_WIDECHAR_API ())
     {
