@@ -21,6 +21,7 @@
 
 
 gboolean abort_break;
+GtkWidget *abort_box = NULL;
 
 
 /******************************************************************************
@@ -29,7 +30,6 @@ gboolean abort_break;
 *                                                                             *
 ******************************************************************************/
 static gint abort_focus;
-static GtkWidget *abort_box = NULL;
 
 
 /* ja:中断ボタンが押された */
